@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2017, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -126,14 +126,17 @@ MASK_SUBPIX_VAR8XH_SSSE3(8)
 MASK_SUBPIX_VAR8XH_SSSE3(4)
 MASK_SUBPIX_VAR4XH_SSSE3(8)
 MASK_SUBPIX_VAR4XH_SSSE3(4)
+
+#if !CONFIG_REALTIME_ONLY
 MASK_SUBPIX_VAR4XH_SSSE3(16)
 MASK_SUBPIX_VAR_SSSE3(16, 4)
 MASK_SUBPIX_VAR8XH_SSSE3(32)
 MASK_SUBPIX_VAR_SSSE3(32, 8)
 MASK_SUBPIX_VAR_SSSE3(64, 16)
 MASK_SUBPIX_VAR_SSSE3(16, 64)
+#endif  // !CONFIG_REALTIME_ONLY
 
-static INLINE __m128i filter_block(const __m128i a, const __m128i b,
+static inline __m128i filter_block(const __m128i a, const __m128i b,
                                    const __m128i filter) {
   __m128i v0 = _mm_unpacklo_epi8(a, b);
   v0 = _mm_maddubs_epi16(v0, filter);
@@ -218,7 +221,7 @@ static void bilinear_filter(const uint8_t *src, int src_stride, int xoffset,
   }
 }
 
-static INLINE __m128i filter_block_2rows(const __m128i *a0, const __m128i *b0,
+static inline __m128i filter_block_2rows(const __m128i *a0, const __m128i *b0,
                                          const __m128i *a1, const __m128i *b1,
                                          const __m128i *filter) {
   __m128i v0 = _mm_unpacklo_epi8(*a0, *b0);
@@ -392,7 +395,7 @@ static void bilinear_filter4xh(const uint8_t *src, int src_stride, int xoffset,
   }
 }
 
-static INLINE void accumulate_block(const __m128i *src, const __m128i *a,
+static inline void accumulate_block(const __m128i *src, const __m128i *a,
                                     const __m128i *b, const __m128i *m,
                                     __m128i *sum, __m128i *sum_sq) {
   const __m128i zero = _mm_setzero_si128();
@@ -704,14 +707,17 @@ HIGHBD_MASK_SUBPIX_VAR_SSSE3(8, 8)
 HIGHBD_MASK_SUBPIX_VAR_SSSE3(8, 4)
 HIGHBD_MASK_SUBPIX_VAR4XH_SSSE3(8)
 HIGHBD_MASK_SUBPIX_VAR4XH_SSSE3(4)
+
+#if !CONFIG_REALTIME_ONLY
 HIGHBD_MASK_SUBPIX_VAR4XH_SSSE3(16)
 HIGHBD_MASK_SUBPIX_VAR_SSSE3(16, 4)
 HIGHBD_MASK_SUBPIX_VAR_SSSE3(8, 32)
 HIGHBD_MASK_SUBPIX_VAR_SSSE3(32, 8)
 HIGHBD_MASK_SUBPIX_VAR_SSSE3(16, 64)
 HIGHBD_MASK_SUBPIX_VAR_SSSE3(64, 16)
+#endif  // !CONFIG_REALTIME_ONLY
 
-static INLINE __m128i highbd_filter_block(const __m128i a, const __m128i b,
+static inline __m128i highbd_filter_block(const __m128i a, const __m128i b,
                                           const __m128i filter) {
   __m128i v0 = _mm_unpacklo_epi16(a, b);
   v0 = _mm_madd_epi16(v0, filter);
@@ -797,7 +803,7 @@ static void highbd_bilinear_filter(const uint16_t *src, int src_stride,
   }
 }
 
-static INLINE __m128i highbd_filter_block_2rows(const __m128i *a0,
+static inline __m128i highbd_filter_block_2rows(const __m128i *a0,
                                                 const __m128i *b0,
                                                 const __m128i *a1,
                                                 const __m128i *b1,
