@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -118,7 +118,7 @@ static const arg_def_t *all_args[] = {
 
 #if CONFIG_LIBYUV
 // Returns 0 on success and returns -1 on failure.
-static INLINE int libyuv_scale(const aom_image_t *src, aom_image_t *dst,
+static inline int libyuv_scale(const aom_image_t *src, aom_image_t *dst,
                                FilterModeEnum mode) {
   if (src->fmt != dst->fmt) {
     fprintf(stderr,
