@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2021, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -48,6 +48,7 @@ static const struct arg_enum_list tuning_enum[] = {
   { "vmaf_neg", AOM_TUNE_VMAF_NEG_MAX_GAIN },
   { "butteraugli", AOM_TUNE_BUTTERAUGLI },
   { "vmaf_saliency_map", AOM_TUNE_VMAF_SALIENCY_MAP },
+  { "iq", AOM_TUNE_IQ },
   { NULL, 0 }
 };
 
@@ -280,10 +281,11 @@ const av1_codec_arg_definitions_t g_av1_codec_arg_defs = {
   .save_as_annexb = ARG_DEF(NULL, "annexb", 1, "Save as Annex-B"),
   .noise_sens = ARG_DEF(NULL, "noise-sensitivity", 1,
                         "Noise sensitivity (frames to blur)"),
-  .sharpness = ARG_DEF(NULL, "sharpness", 1,
-                       "Bias towards block sharpness in rate-distortion "
-                       "optimization of transform coefficients "
-                       "(0..7), default is 0"),
+  .sharpness =
+      ARG_DEF(NULL, "sharpness", 1,
+              "Bias towards block sharpness in rate-distortion optimization of "
+              "transform coefficients and (in all intra mode only) reduce "
+              "block edge filtering for better sharpness (0..7), default is 0"),
   .static_thresh =
       ARG_DEF(NULL, "static-thresh", 1, "Motion detection threshold"),
   .auto_altref =
@@ -315,6 +317,8 @@ const av1_codec_arg_definitions_t g_av1_codec_arg_defs = {
       ARG_DEF(NULL, "tile-columns", 1, "Number of tile columns to use, log2"),
   .tile_rows =
       ARG_DEF(NULL, "tile-rows", 1, "Number of tile rows to use, log2"),
+  .auto_tiles = ARG_DEF(NULL, "auto-tiles", 1,
+                        "Enable auto tiles (0: false (default), 1: true)"),
   .enable_tpl_model = ARG_DEF(NULL, "enable-tpl-model", 1,
                               "RDO based on frame temporal dependency "
                               "(0: off, 1: backward source based); "
@@ -333,7 +337,8 @@ const av1_codec_arg_definitions_t g_av1_codec_arg_defs = {
   .enable_cdef = ARG_DEF(
       NULL, "enable-cdef", 1,
       "Enable the constrained directional enhancement filter (0: false, "
-      "1: true (default), 2: disable for non-reference frames)"),
+      "1: true (default), 2: disable for non-reference frames, 3: enable "
+      "adaptively based on frame qindex)"),
   .enable_restoration = ARG_DEF(NULL, "enable-restoration", 1,
                                 "Enable the loop restoration filter (0: false "
                                 "(default in realtime mode), "
@@ -457,10 +462,12 @@ const av1_codec_arg_definitions_t g_av1_codec_arg_defs = {
   .enable_qm =
       ARG_DEF(NULL, "enable-qm", 1,
               "Enable quantisation matrices (0: false (default), 1: true)"),
-  .qm_min = ARG_DEF(NULL, "qm-min", 1,
-                    "Min quant matrix flatness (0..15), default is 8"),
+  .qm_min = ARG_DEF(
+      NULL, "qm-min", 1,
+      "Min quant matrix flatness (0..15), default is 5 (4 for all intra mode)"),
   .qm_max = ARG_DEF(NULL, "qm-max", 1,
-                    "Max quant matrix flatness (0..15), default is 15"),
+                    "Max quant matrix flatness (0..15), default is 9 (10 for "
+                    "all intra mode)"),
   .reduced_tx_type_set = ARG_DEF(NULL, "reduced-tx-type-set", 1,
                                  "Use reduced set of transform types"),
   .use_intra_dct_only =
@@ -545,8 +552,8 @@ const av1_codec_arg_definitions_t g_av1_codec_arg_defs = {
       ARG_DEF(NULL, "deltaq-mode", 1,
               "Delta qindex mode (0: off, 1: deltaq objective (default), "
               "2: deltaq placeholder, 3: key frame visual quality, 4: user "
-              "rating based visual quality optimization); "
-              "requires --enable-tpl-model=1"),
+              "rating based visual quality optimization, 5: HDR video, 6: "
+              "Variance Boost all intra); requires --enable-tpl-model=1"),
   .deltaq_strength = ARG_DEF(NULL, "deltaq-strength", 1,
                              "Deltaq strength for"
                              " --deltaq-mode=4 (%)"),
@@ -667,10 +674,10 @@ const av1_codec_arg_definitions_t g_av1_codec_arg_defs = {
       "frames (default), 2: Disable loopfilter for non-reference frames, 3: "
       "Disable loopfilter for frames with low motion)"),
 
-  .auto_intra_tools_off = ARG_DEF(
-      NULL, "auto-intra-tools-off", 1,
-      "Automatically turn off several intra coding tools for allintra mode; "
-      "only in effect if --deltaq-mode=3"),
+  .auto_intra_tools_off =
+      ARG_DEF(NULL, "auto-intra-tools-off", 1,
+              "Automatically turn off several intra coding tools for all intra "
+              "mode; only in effect if --deltaq-mode=3"),
 
   .two_pass_input =
       ARG_DEF(NULL, "two-pass-input", 1,
