@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2024, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2024, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -22,13 +22,14 @@
 #include "aom_ports/mem.h"
 #include "av1/common/convolve.h"
 #include "av1/common/filter.h"
+#include "av1/common/arm/highbd_convolve_sve2.h"
 
 DECLARE_ALIGNED(16, static const uint16_t, kDotProdTbl[32]) = {
   0, 1, 2, 3, 1, 2, 3, 4, 2, 3, 4, 5, 3, 4, 5, 6,
   4, 5, 6, 7, 5, 6, 7, 0, 6, 7, 0, 1, 7, 0, 1, 2,
 };
 
-static INLINE uint16x4_t convolve12_4_x(
+static inline uint16x4_t convolve12_4_x(
     int16x8_t s0, int16x8_t s1, int16x8_t filter_0_7, int16x8_t filter_4_11,
     const int64x2_t offset, uint16x8x4_t permute_tbl, uint16x4_t max) {
   int16x8_t permuted_samples[6];
@@ -55,7 +56,7 @@ static INLINE uint16x4_t convolve12_4_x(
   return vmin_u16(res, max);
 }
 
-static INLINE uint16x8_t convolve12_8_x(int16x8_t s0, int16x8_t s1,
+static inline uint16x8_t convolve12_8_x(int16x8_t s0, int16x8_t s1,
                                         int16x8_t s2, int16x8_t filter_0_7,
                                         int16x8_t filter_4_11, int64x2_t offset,
                                         uint16x8x4_t permute_tbl,
@@ -99,7 +100,7 @@ static INLINE uint16x8_t convolve12_8_x(int16x8_t s0, int16x8_t s1,
   return vminq_u16(res, max);
 }
 
-static INLINE void highbd_convolve_x_sr_12tap_sve2(
+static inline void highbd_convolve_x_sr_12tap_sve2(
     const uint16_t *src, int src_stride, uint16_t *dst, int dst_stride,
     int width, int height, const int16_t *y_filter_ptr,
     ConvolveParams *conv_params, int bd) {
@@ -181,7 +182,7 @@ static INLINE void highbd_convolve_x_sr_12tap_sve2(
   }
 }
 
-static INLINE uint16x8_t convolve8_8_x(int16x8_t s0[8], int16x8_t filter,
+static inline uint16x8_t convolve8_8_x(int16x8_t s0[8], int16x8_t filter,
                                        int64x2_t offset, uint16x8_t max) {
   int64x2_t sum[8];
   sum[0] = aom_sdotq_s16(offset, s0[0], filter);
@@ -207,7 +208,7 @@ static INLINE uint16x8_t convolve8_8_x(int16x8_t s0[8], int16x8_t filter,
   return vminq_u16(res, max);
 }
 
-static INLINE void highbd_convolve_x_sr_8tap_sve2(
+static inline void highbd_convolve_x_sr_8tap_sve2(
     const uint16_t *src, int src_stride, uint16_t *dst, int dst_stride,
     int width, int height, const int16_t *y_filter_ptr,
     ConvolveParams *conv_params, int bd) {
@@ -257,7 +258,7 @@ DECLARE_ALIGNED(16, static const uint16_t, kDeinterleaveTbl[8]) = {
 };
 // clang-format on
 
-static INLINE uint16x4_t convolve4_4_x(int16x8_t s0, int16x8_t filter,
+static inline uint16x4_t convolve4_4_x(int16x8_t s0, int16x8_t filter,
                                        int64x2_t offset,
                                        uint16x8x2_t permute_tbl,
                                        uint16x4_t max) {
@@ -273,7 +274,7 @@ static INLINE uint16x4_t convolve4_4_x(int16x8_t s0, int16x8_t filter,
   return vmin_u16(res, max);
 }
 
-static INLINE uint16x8_t convolve4_8_x(int16x8_t s0[4], int16x8_t filter,
+static inline uint16x8_t convolve4_8_x(int16x8_t s0[4], int16x8_t filter,
                                        int64x2_t offset, uint16x8_t tbl,
                                        uint16x8_t max) {
   int64x2_t sum04 = aom_svdot_lane_s16(offset, s0[0], filter, 0);
@@ -291,7 +292,7 @@ static INLINE uint16x8_t convolve4_8_x(int16x8_t s0[4], int16x8_t filter,
   return vminq_u16(res, max);
 }
 
-static INLINE void highbd_convolve_x_sr_4tap_sve2(
+static inline void highbd_convolve_x_sr_4tap_sve2(
     const uint16_t *src, int src_stride, uint16_t *dst, int dst_stride,
     int width, int height, const int16_t *x_filter_ptr,
     ConvolveParams *conv_params, int bd) {
@@ -398,86 +399,7 @@ void av1_highbd_convolve_x_sr_sve2(const uint16_t *src, int src_stride,
                                  x_filter_ptr, conv_params, bd);
 }
 
-// clang-format off
-DECLARE_ALIGNED(16, static const uint16_t, kDotProdMergeBlockTbl[24]) = {
-  // Shift left and insert new last column in transposed 4x4 block.
-  1, 2, 3, 0, 5, 6, 7, 4,
-  // Shift left and insert two new columns in transposed 4x4 block.
-  2, 3, 0, 1, 6, 7, 4, 5,
-  // Shift left and insert three new columns in transposed 4x4 block.
-  3, 0, 1, 2, 7, 4, 5, 6,
-};
-// clang-format on
-
-static INLINE void transpose_concat_4x4(int16x4_t s0, int16x4_t s1,
-                                        int16x4_t s2, int16x4_t s3,
-                                        int16x8_t res[2]) {
-  // Transpose 16-bit elements and concatenate result rows as follows:
-  // s0: 00, 01, 02, 03
-  // s1: 10, 11, 12, 13
-  // s2: 20, 21, 22, 23
-  // s3: 30, 31, 32, 33
-  //
-  // res[0]: 00 10 20 30 01 11 21 31
-  // res[1]: 02 12 22 32 03 13 23 33
-
-  int16x8_t s0q = vcombine_s16(s0, vdup_n_s16(0));
-  int16x8_t s1q = vcombine_s16(s1, vdup_n_s16(0));
-  int16x8_t s2q = vcombine_s16(s2, vdup_n_s16(0));
-  int16x8_t s3q = vcombine_s16(s3, vdup_n_s16(0));
-
-  int32x4_t s01 = vreinterpretq_s32_s16(vzip1q_s16(s0q, s1q));
-  int32x4_t s23 = vreinterpretq_s32_s16(vzip1q_s16(s2q, s3q));
-
-  int32x4x2_t s0123 = vzipq_s32(s01, s23);
-
-  res[0] = vreinterpretq_s16_s32(s0123.val[0]);
-  res[1] = vreinterpretq_s16_s32(s0123.val[1]);
-}
-
-static INLINE void transpose_concat_8x4(int16x8_t s0, int16x8_t s1,
-                                        int16x8_t s2, int16x8_t s3,
-                                        int16x8_t res[4]) {
-  // Transpose 16-bit elements and concatenate result rows as follows:
-  // s0: 00, 01, 02, 03, 04, 05, 06, 07
-  // s1: 10, 11, 12, 13, 14, 15, 16, 17
-  // s2: 20, 21, 22, 23, 24, 25, 26, 27
-  // s3: 30, 31, 32, 33, 34, 35, 36, 37
-  //
-  // res[0]: 00 10 20 30 01 11 21 31
-  // res[1]: 02 12 22 32 03 13 23 33
-  // res[2]: 04 14 24 34 05 15 25 35
-  // res[3]: 06 16 26 36 07 17 27 37
-
-  int16x8x2_t tr01_16 = vzipq_s16(s0, s1);
-  int16x8x2_t tr23_16 = vzipq_s16(s2, s3);
-
-  int32x4x2_t tr01_32 = vzipq_s32(vreinterpretq_s32_s16(tr01_16.val[0]),
-                                  vreinterpretq_s32_s16(tr23_16.val[0]));
-  int32x4x2_t tr23_32 = vzipq_s32(vreinterpretq_s32_s16(tr01_16.val[1]),
-                                  vreinterpretq_s32_s16(tr23_16.val[1]));
-
-  res[0] = vreinterpretq_s16_s32(tr01_32.val[0]);
-  res[1] = vreinterpretq_s16_s32(tr01_32.val[1]);
-  res[2] = vreinterpretq_s16_s32(tr23_32.val[0]);
-  res[3] = vreinterpretq_s16_s32(tr23_32.val[1]);
-}
-
-static INLINE void aom_tbl2x4_s16(int16x8_t t0[4], int16x8_t t1[4],
-                                  uint16x8_t tbl, int16x8_t res[4]) {
-  res[0] = aom_tbl2_s16(t0[0], t1[0], tbl);
-  res[1] = aom_tbl2_s16(t0[1], t1[1], tbl);
-  res[2] = aom_tbl2_s16(t0[2], t1[2], tbl);
-  res[3] = aom_tbl2_s16(t0[3], t1[3], tbl);
-}
-
-static INLINE void aom_tbl2x2_s16(int16x8_t t0[2], int16x8_t t1[2],
-                                  uint16x8_t tbl, int16x8_t res[2]) {
-  res[0] = aom_tbl2_s16(t0[0], t1[0], tbl);
-  res[1] = aom_tbl2_s16(t0[1], t1[1], tbl);
-}
-
-static INLINE uint16x4_t highbd_convolve12_4_y(int16x8_t s0[2], int16x8_t s1[2],
+static inline uint16x4_t highbd_convolve12_4_y(int16x8_t s0[2], int16x8_t s1[2],
                                                int16x8_t s2[2],
                                                int16x8_t filter_0_7,
                                                int16x8_t filter_4_11,
@@ -499,7 +421,7 @@ static INLINE uint16x4_t highbd_convolve12_4_y(int16x8_t s0[2], int16x8_t s1[2],
   return vmin_u16(res, max);
 }
 
-static INLINE void highbd_convolve_y_sr_12tap_sve2(
+static inline void highbd_convolve_y_sr_12tap_sve2(
     const uint16_t *src, int src_stride, uint16_t *dst, int dst_stride,
     int width, int height, const int16_t *y_filter_ptr, int bd) {
   const int16x8_t y_filter_0_7 = vld1q_s16(y_filter_ptr);
@@ -596,7 +518,7 @@ static INLINE void highbd_convolve_y_sr_12tap_sve2(
   } while (width != 0);
 }
 
-static INLINE uint16x4_t highbd_convolve8_4_y(int16x8_t samples_lo[2],
+static inline uint16x4_t highbd_convolve8_4_y(int16x8_t samples_lo[2],
                                               int16x8_t samples_hi[2],
                                               int16x8_t filter,
                                               uint16x4_t max) {
@@ -613,7 +535,7 @@ static INLINE uint16x4_t highbd_convolve8_4_y(int16x8_t samples_lo[2],
   return vmin_u16(res, max);
 }
 
-static INLINE uint16x8_t highbd_convolve8_8_y(int16x8_t samples_lo[4],
+static inline uint16x8_t highbd_convolve8_8_y(int16x8_t samples_lo[4],
                                               int16x8_t samples_hi[4],
                                               int16x8_t filter,
                                               uint16x8_t max) {
@@ -640,10 +562,11 @@ static INLINE uint16x8_t highbd_convolve8_8_y(int16x8_t samples_lo[4],
   return vminq_u16(res, max);
 }
 
-void highbd_convolve_y_sr_8tap_sve2(const uint16_t *src, ptrdiff_t src_stride,
-                                    uint16_t *dst, ptrdiff_t dst_stride,
-                                    int width, int height,
-                                    const int16_t *filter_y, int bd) {
+static void highbd_convolve_y_sr_8tap_sve2(const uint16_t *src,
+                                           ptrdiff_t src_stride, uint16_t *dst,
+                                           ptrdiff_t dst_stride, int width,
+                                           int height, const int16_t *filter_y,
+                                           int bd) {
   assert(width >= 4 && height >= 4);
 
   const int16x8_t y_filter = vld1q_s16(filter_y);
@@ -783,7 +706,7 @@ void highbd_convolve_y_sr_8tap_sve2(const uint16_t *src, ptrdiff_t src_stride,
   }
 }
 
-static INLINE uint16x4_t highbd_convolve4_4_y(int16x8_t samples[2],
+static inline uint16x4_t highbd_convolve4_4_y(int16x8_t samples[2],
                                               int16x8_t filter,
                                               uint16x4_t max) {
   int64x2_t sum01 = aom_svdot_lane_s16(vdupq_n_s64(0), samples[0], filter, 0);
@@ -794,7 +717,7 @@ static INLINE uint16x4_t highbd_convolve4_4_y(int16x8_t samples[2],
   return vmin_u16(res, max);
 }
 
-static INLINE uint16x8_t highbd_convolve4_8_y(int16x8_t samples[4],
+static inline uint16x8_t highbd_convolve4_8_y(int16x8_t samples[4],
                                               int16x8_t filter,
                                               uint16x8_t max) {
   int64x2_t sum01 = aom_svdot_lane_s16(vdupq_n_s64(0), samples[0], filter, 0);
@@ -809,10 +732,11 @@ static INLINE uint16x8_t highbd_convolve4_8_y(int16x8_t samples[4],
   return vminq_u16(res, max);
 }
 
-void highbd_convolve_y_sr_4tap_sve2(const uint16_t *src, ptrdiff_t src_stride,
-                                    uint16_t *dst, ptrdiff_t dst_stride,
-                                    int width, int height,
-                                    const int16_t *filter_y, int bd) {
+static void highbd_convolve_y_sr_4tap_sve2(const uint16_t *src,
+                                           ptrdiff_t src_stride, uint16_t *dst,
+                                           ptrdiff_t dst_stride, int width,
+                                           int height, const int16_t *filter_y,
+                                           int bd) {
   assert(width >= 4 && height >= 4);
 
   const int16x8_t y_filter =
@@ -940,7 +864,7 @@ void av1_highbd_convolve_y_sr_sve2(const uint16_t *src, int src_stride,
                                  y_filter_ptr, bd);
 }
 
-static INLINE uint16x4_t convolve12_4_2d_h(
+static inline uint16x4_t convolve12_4_2d_h(
     int16x8_t s0, int16x8_t s1, int16x8_t filter_0_7, int16x8_t filter_4_11,
     const int64x2_t offset, int32x4_t shift, uint16x8x4_t permute_tbl) {
   int16x8_t permuted_samples[6];
@@ -966,7 +890,7 @@ static INLINE uint16x4_t convolve12_4_2d_h(
   return vqmovun_s32(sum0123);
 }
 
-static INLINE uint16x8_t convolve12_8_2d_h(int16x8_t s0, int16x8_t s1,
+static inline uint16x8_t convolve12_8_2d_h(int16x8_t s0, int16x8_t s1,
                                            int16x8_t s2, int16x8_t filter_0_7,
                                            int16x8_t filter_4_11,
                                            int64x2_t offset, int32x4_t shift,
@@ -1010,7 +934,7 @@ static INLINE uint16x8_t convolve12_8_2d_h(int16x8_t s0, int16x8_t s1,
   return vcombine_u16(vqmovun_s32(sum0123), vqmovun_s32(sum4567));
 }
 
-static INLINE void highbd_convolve_2d_sr_horiz_12tap_sve2(
+static inline void highbd_convolve_2d_sr_horiz_12tap_sve2(
     const uint16_t *src, int src_stride, uint16_t *dst, int dst_stride,
     int width, int height, const int16_t *y_filter_ptr,
     ConvolveParams *conv_params, const int x_offset) {
@@ -1093,7 +1017,7 @@ static INLINE void highbd_convolve_2d_sr_horiz_12tap_sve2(
   }
 }
 
-static INLINE uint16x8_t convolve8_8_2d_h(int16x8_t s0[8], int16x8_t filter,
+static inline uint16x8_t convolve8_8_2d_h(int16x8_t s0[8], int16x8_t filter,
                                           int64x2_t offset, int32x4_t shift) {
   int64x2_t sum[8];
   sum[0] = aom_sdotq_s16(offset, s0[0], filter);
@@ -1119,7 +1043,7 @@ static INLINE uint16x8_t convolve8_8_2d_h(int16x8_t s0[8], int16x8_t filter,
   return vcombine_u16(vqmovun_s32(sum0123), vqmovun_s32(sum4567));
 }
 
-static INLINE void highbd_convolve_2d_sr_horiz_8tap_sve2(
+static inline void highbd_convolve_2d_sr_horiz_8tap_sve2(
     const uint16_t *src, int src_stride, uint16_t *dst, int dst_stride,
     int width, int height, const int16_t *y_filter_ptr,
     ConvolveParams *conv_params, const int x_offset) {
@@ -1162,7 +1086,7 @@ static INLINE void highbd_convolve_2d_sr_horiz_8tap_sve2(
   } while (height > 0);
 }
 
-static INLINE uint16x4_t convolve4_4_2d_h(int16x8_t s0, int16x8_t filter,
+static inline uint16x4_t convolve4_4_2d_h(int16x8_t s0, int16x8_t filter,
                                           int64x2_t offset, int32x4_t shift,
                                           uint16x8x2_t permute_tbl) {
   int16x8_t permuted_samples0 = aom_tbl_s16(s0, permute_tbl.val[0]);
@@ -1176,7 +1100,7 @@ static INLINE uint16x4_t convolve4_4_2d_h(int16x8_t s0, int16x8_t filter,
   return vqmovun_s32(sum0123);
 }
 
-static INLINE uint16x8_t convolve4_8_2d_h(int16x8_t s0[8], int16x8_t filter,
+static inline uint16x8_t convolve4_8_2d_h(int16x8_t s0[8], int16x8_t filter,
                                           int64x2_t offset, int32x4_t shift,
                                           uint16x8_t tbl) {
   int64x2_t sum04 = aom_svdot_lane_s16(offset, s0[0], filter, 0);
@@ -1194,7 +1118,7 @@ static INLINE uint16x8_t convolve4_8_2d_h(int16x8_t s0[8], int16x8_t filter,
   return aom_tbl_u16(res, tbl);
 }
 
-static INLINE void highbd_convolve_2d_sr_horiz_4tap_sve2(
+static inline void highbd_convolve_2d_sr_horiz_4tap_sve2(
     const uint16_t *src, int src_stride, uint16_t *dst, int dst_stride,
     int width, int height, const int16_t *x_filter_ptr,
     ConvolveParams *conv_params, const int x_offset) {
@@ -1261,7 +1185,7 @@ static INLINE void highbd_convolve_2d_sr_horiz_4tap_sve2(
   }
 }
 
-static INLINE uint16x4_t highbd_convolve12_4_2d_v(
+static inline uint16x4_t highbd_convolve12_4_2d_v(
     int16x8_t s0[2], int16x8_t s1[2], int16x8_t s2[2], int16x8_t filter_0_7,
     int16x8_t filter_4_11, int32x4_t shift, int64x2_t offset, uint16x4_t max) {
   int64x2_t sum01 = aom_svdot_lane_s16(offset, s0[0], filter_0_7, 0);
@@ -1280,7 +1204,7 @@ static INLINE uint16x4_t highbd_convolve12_4_2d_v(
   return vmin_u16(res, max);
 }
 
-static INLINE void highbd_convolve_2d_sr_vert_12tap_sve2(
+static inline void highbd_convolve_2d_sr_vert_12tap_sve2(
     const uint16_t *src, int src_stride, uint16_t *dst, int dst_stride,
     int width, int height, const int16_t *y_filter_ptr,
     ConvolveParams *conv_params, int bd, const int y_offset) {
@@ -1383,7 +1307,7 @@ static INLINE void highbd_convolve_2d_sr_vert_12tap_sve2(
   } while (width != 0);
 }
 
-static INLINE uint16x4_t highbd_convolve8_4_2d_v(
+static inline uint16x4_t highbd_convolve8_4_2d_v(
     int16x8_t samples_lo[2], int16x8_t samples_hi[2], int16x8_t filter,
     int32x4_t shift, int64x2_t offset, uint16x4_t max) {
   int64x2_t sum01 = aom_svdot_lane_s16(offset, samples_lo[0], filter, 0);
@@ -1399,7 +1323,7 @@ static INLINE uint16x4_t highbd_convolve8_4_2d_v(
   return vmin_u16(res, max);
 }
 
-static INLINE uint16x8_t highbd_convolve8_8_2d_v(
+static inline uint16x8_t highbd_convolve8_8_2d_v(
     int16x8_t samples_lo[4], int16x8_t samples_hi[4], int16x8_t filter,
     int32x4_t shift, int64x2_t offset, uint16x8_t max) {
   int64x2_t sum01 = aom_svdot_lane_s16(offset, samples_lo[0], filter, 0);
@@ -1424,12 +1348,10 @@ static INLINE uint16x8_t highbd_convolve8_8_2d_v(
   return vminq_u16(res, max);
 }
 
-void highbd_convolve_2d_sr_vert_8tap_sve2(const uint16_t *src,
-                                          ptrdiff_t src_stride, uint16_t *dst,
-                                          ptrdiff_t dst_stride, int width,
-                                          int height, const int16_t *filter_y,
-                                          ConvolveParams *conv_params, int bd,
-                                          const int y_offset) {
+static void highbd_convolve_2d_sr_vert_8tap_sve2(
+    const uint16_t *src, ptrdiff_t src_stride, uint16_t *dst,
+    ptrdiff_t dst_stride, int width, int height, const int16_t *filter_y,
+    ConvolveParams *conv_params, int bd, const int y_offset) {
   assert(width >= 4 && height >= 4);
   const int64x2_t offset = vdupq_n_s64(y_offset);
   const int32x4_t shift = vdupq_n_s32(-conv_params->round_1);
@@ -1579,7 +1501,7 @@ void highbd_convolve_2d_sr_vert_8tap_sve2(const uint16_t *src,
   }
 }
 
-static INLINE uint16x4_t highbd_convolve4_4_2d_v(int16x8_t samples[2],
+static inline uint16x4_t highbd_convolve4_4_2d_v(int16x8_t samples[2],
                                                  int16x8_t filter,
                                                  int32x4_t shift,
                                                  int64x2_t offset,
@@ -1594,7 +1516,7 @@ static INLINE uint16x4_t highbd_convolve4_4_2d_v(int16x8_t samples[2],
   return vmin_u16(res, max);
 }
 
-static INLINE uint16x8_t highbd_convolve4_8_2d_v(int16x8_t samples[4],
+static inline uint16x8_t highbd_convolve4_8_2d_v(int16x8_t samples[4],
                                                  int16x8_t filter,
                                                  int32x4_t shift,
                                                  int64x2_t offset,
@@ -1614,12 +1536,10 @@ static INLINE uint16x8_t highbd_convolve4_8_2d_v(int16x8_t samples[4],
   return vminq_u16(res, max);
 }
 
-void highbd_convolve_2d_sr_vert_4tap_sve2(const uint16_t *src,
-                                          ptrdiff_t src_stride, uint16_t *dst,
-                                          ptrdiff_t dst_stride, int width,
-                                          int height, const int16_t *filter_y,
-                                          ConvolveParams *conv_params, int bd,
-                                          const int y_offset) {
+static void highbd_convolve_2d_sr_vert_4tap_sve2(
+    const uint16_t *src, ptrdiff_t src_stride, uint16_t *dst,
+    ptrdiff_t dst_stride, int width, int height, const int16_t *filter_y,
+    ConvolveParams *conv_params, int bd, const int y_offset) {
   assert(width >= 4 && height >= 4);
   const int64x2_t offset = vdupq_n_s64(y_offset);
   const int32x4_t shift = vdupq_n_s32(-conv_params->round_1);
