@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2018, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -17,9 +17,6 @@
 
 #define DWT_MAX_LENGTH 64
 
-void av1_fdwt8x8_uint8_input_c(const uint8_t *input, tran_low_t *output,
-                               int stride, int hbd);
-
 int64_t av1_haar_ac_sad_mxn_uint8_input(const uint8_t *input, int stride,
                                         int hbd, int num_8x8_rows,
                                         int num_8x8_cols);
