@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2018, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -102,7 +102,7 @@ void av1_hash_table_init(IntraBCHashInfo *intrabc_hash_info) {
   intrabc_hash_info->intrabc_hash_table.p_lookup_table = NULL;
 }
 
-void av1_hash_table_clear_all(hash_table *p_hash_table) {
+static void clear_all(hash_table *p_hash_table) {
   if (p_hash_table->p_lookup_table == NULL) {
     return;
   }
@@ -116,14 +116,14 @@ void av1_hash_table_clear_all(hash_table *p_hash_table) {
 }
 
 void av1_hash_table_destroy(hash_table *p_hash_table) {
-  av1_hash_table_clear_all(p_hash_table);
+  clear_all(p_hash_table);
   aom_free(p_hash_table->p_lookup_table);
   p_hash_table->p_lookup_table = NULL;
 }
 
 bool av1_hash_table_create(hash_table *p_hash_table) {
   if (p_hash_table->p_lookup_table != NULL) {
-    av1_hash_table_clear_all(p_hash_table);
+    clear_all(p_hash_table);
     return true;
   }
   p_hash_table->p_lookup_table =
@@ -170,24 +170,6 @@ Iterator av1_hash_get_first_iterator(hash_table *p_hash_table,
   return aom_vector_begin(p_hash_table->p_lookup_table[hash_value]);
 }
 
-int32_t av1_has_exact_match(hash_table *p_hash_table, uint32_t hash_value1,
-                            uint32_t hash_value2) {
-  if (p_hash_table->p_lookup_table[hash_value1] == NULL) {
-    return 0;
-  }
-  Iterator iterator =
-      aom_vector_begin(p_hash_table->p_lookup_table[hash_value1]);
-  Iterator last = aom_vector_end(p_hash_table->p_lookup_table[hash_value1]);
-  for (; !aom_iterator_equals(&iterator, &last);
-       aom_iterator_increment(&iterator)) {
-    if ((*(block_hash *)aom_iterator_get(&iterator)).hash_value2 ==
-        hash_value2) {
-      return 1;
-    }
-  }
-  return 0;
-}
-
 void av1_generate_block_2x2_hash_value(IntraBCHashInfo *intrabc_hash_info,
                                        const YV12_BUFFER_CONFIG *picture,
                                        uint32_t *pic_block_hash[2],
