@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -443,7 +443,7 @@ using ::testing::Combine;
 using ::testing::Values;
 using ::testing::ValuesIn;
 
-#if HAVE_SSE2
+#if AOM_ARCH_X86 && HAVE_SSE2
 static TX_SIZE fwd_txfm_for_sse2[] = {
   TX_4X4,
   TX_8X8,
@@ -469,15 +469,14 @@ static TX_SIZE fwd_txfm_for_sse2[] = {
 INSTANTIATE_TEST_SUITE_P(SSE2, AV1FwdTxfm2dTest,
                          Combine(ValuesIn(fwd_txfm_for_sse2),
                                  Values(av1_lowbd_fwd_txfm_sse2)));
-#endif  // HAVE_SSE2
+#endif  // AOM_ARCH_X86 && HAVE_SSE2
 
 #if HAVE_SSE4_1
-static TX_SIZE fwd_txfm_for_sse41[] = {
-  TX_4X4,
-  TX_64X64,
-  TX_32X64,
-  TX_64X32,
-};
+static TX_SIZE fwd_txfm_for_sse41[] = { TX_4X4,   TX_8X8,   TX_16X16, TX_32X32,
+                                        TX_64X64, TX_4X8,   TX_8X4,   TX_8X16,
+                                        TX_16X8,  TX_16X32, TX_32X16, TX_32X64,
+                                        TX_64X32, TX_4X16,  TX_16X4,  TX_8X32,
+                                        TX_32X8,  TX_16X64, TX_64X16 };
 
 INSTANTIATE_TEST_SUITE_P(SSE4_1, AV1FwdTxfm2dTest,
                          Combine(ValuesIn(fwd_txfm_for_sse41),
@@ -661,7 +660,7 @@ static TX_SIZE Highbd_fwd_txfm_for_sse4_1[] = {
   TX_8X16, TX_16X8, TX_16X32, TX_32X16, TX_32X64, TX_64X32,
 #if !CONFIG_REALTIME_ONLY
   TX_4X16, TX_16X4, TX_8X32,  TX_32X8,  TX_16X64, TX_64X16,
-#endif
+#endif  // !CONFIG_REALTIME_ONLY
 };
 
 INSTANTIATE_TEST_SUITE_P(SSE4_1, AV1HighbdFwdTxfm2dTest,
@@ -680,8 +679,10 @@ INSTANTIATE_TEST_SUITE_P(AVX2, AV1HighbdFwdTxfm2dTest,
 #if HAVE_NEON
 static TX_SIZE Highbd_fwd_txfm_for_neon[] = {
   TX_4X4,  TX_8X8,  TX_16X16, TX_32X32, TX_64X64, TX_4X8,   TX_8X4,
-  TX_8X16, TX_16X8, TX_16X32, TX_32X16, TX_32X64, TX_64X32, TX_4X16,
-  TX_16X4, TX_8X32, TX_32X8,  TX_16X64, TX_64X16
+  TX_8X16, TX_16X8, TX_16X32, TX_32X16, TX_32X64, TX_64X32,
+#if !CONFIG_REALTIME_ONLY
+  TX_4X16, TX_16X4, TX_8X32,  TX_32X8,  TX_16X64, TX_64X16
+#endif  // !CONFIG_REALTIME_ONLY
 };
 
 INSTANTIATE_TEST_SUITE_P(NEON, AV1HighbdFwdTxfm2dTest,
